@@ -478,8 +478,8 @@ do_sync_2_path_call (GFile *file1,
 	{
 	  g_mount_info_unref (mount_info1);
 	  /* For copy this will cause the fallback code to be involved */
-	  g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
-		       "%s", _("Operation not supported, files on different mounts"));
+	  g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+			       _("Operation not supported, files on different mounts"));
 	  return NULL;
 	}
     }
@@ -783,8 +783,8 @@ g_daemon_file_query_info (GFile                *file,
   if (!dbus_message_iter_init (reply, &iter) ||
       (dbus_message_iter_get_arg_type (&iter) != DBUS_TYPE_STRUCT))
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		   "%s", _("Invalid return value from get_info"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+			   _("Invalid return value from get_info"));
       goto out;
     }
 
@@ -992,8 +992,8 @@ g_daemon_file_read (GFile *file,
 			      DBUS_TYPE_INVALID))
     {
       dbus_message_unref (reply);
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		   "%s", _("Invalid return value from open"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+			   _("Invalid return value from open"));
       return NULL;
     }
   
@@ -1002,8 +1002,8 @@ g_daemon_file_read (GFile *file,
   fd = _g_dbus_connection_get_fd_sync (connection, fd_id);
   if (fd == -1)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		   "%s", _("Didn't get stream file descriptor"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+			   _("Didn't get stream file descriptor"));
       return NULL;
     }
   
@@ -1051,8 +1051,8 @@ g_daemon_file_append_to (GFile *file,
 			      DBUS_TYPE_INVALID))
     {
       dbus_message_unref (reply);
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		   "%s", _("Invalid return value from open"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+			   _("Invalid return value from open"));
       return NULL;
     }
   
@@ -1061,8 +1061,8 @@ g_daemon_file_append_to (GFile *file,
   fd = _g_dbus_connection_get_fd_sync (connection, fd_id);
   if (fd == -1)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		   "%s", _("Didn't get stream file descriptor"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+			   _("Didn't get stream file descriptor"));
       return NULL;
     }
   
@@ -1110,8 +1110,8 @@ g_daemon_file_create (GFile *file,
 			      DBUS_TYPE_INVALID))
     {
       dbus_message_unref (reply);
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		   "%s", _("Invalid return value from open"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+			   _("Invalid return value from open"));
       return NULL;
     }
   
@@ -1120,8 +1120,8 @@ g_daemon_file_create (GFile *file,
   fd = _g_dbus_connection_get_fd_sync (connection, fd_id);
   if (fd == -1)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		   "%s", _("Didn't get stream file descriptor"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+			   _("Didn't get stream file descriptor"));
       return NULL;
     }
   
@@ -1172,8 +1172,8 @@ g_daemon_file_replace (GFile *file,
 			      DBUS_TYPE_INVALID))
     {
       dbus_message_unref (reply);
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		   "%s", _("Invalid return value from open"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+			   _("Invalid return value from open"));
       return NULL;
     }
   
@@ -1182,8 +1182,8 @@ g_daemon_file_replace (GFile *file,
   fd = _g_dbus_connection_get_fd_sync (connection, fd_id);
   if (fd == -1)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		   "%s", _("Didn't get stream file descriptor"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+			   _("Didn't get stream file descriptor"));
       return NULL;
     }
   
@@ -1530,8 +1530,8 @@ g_daemon_file_query_filesystem_info (GFile                *file,
   if (!dbus_message_iter_init (reply, &iter) ||
       (dbus_message_iter_get_arg_type (&iter) != DBUS_TYPE_STRUCT))
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		   "%s", _("Invalid return value from get_filesystem_info"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+			   _("Invalid return value from get_filesystem_info"));
       goto out;
     }
 
@@ -1640,11 +1640,11 @@ g_daemon_file_find_enclosing_mount (GFile *file,
 	return G_MOUNT (mount);
     }
 
-  g_set_error (error, G_IO_ERROR,
-	       G_IO_ERROR_NOT_FOUND,
+  g_set_error_literal (error, G_IO_ERROR,
+		       G_IO_ERROR_NOT_FOUND,
   /* translators: this is an error message when there is no user visible "mount" object
      corresponding to a particular path/uri */
-	       "%s", _("Could not find enclosing mount"));
+		       _("Could not find enclosing mount"));
   return NULL;
 }
 
@@ -1715,8 +1715,8 @@ g_daemon_file_set_display_name (GFile *file,
 				      G_DBUS_TYPE_CSTRING, &new_path,
 				      0))
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		   "%s", _("Invalid return value from query_filesystem_info"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+			   _("Invalid return value from query_filesystem_info"));
       goto out;
     }
 
@@ -1958,7 +1958,7 @@ g_daemon_file_copy (GFile                  *source,
   if (!G_IS_DAEMON_FILE (destination))
     {
       /* Fall back to default move */
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, "%s", "Move not supported");
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, "Move not supported");
       return FALSE;
     }
 
@@ -1975,8 +1975,8 @@ g_daemon_file_copy (GFile                  *source,
       if (local_path == NULL)
 	{
 	  /* This will cause the fallback code to be involved */
-	  g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
-		       "%s", _("Operation not supported, files on different mounts"));
+	  g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+			       _("Operation not supported, files on different mounts"));
 	  return FALSE;
 	}
     }
@@ -2048,7 +2048,7 @@ g_daemon_file_move (GFile                  *source,
       !G_IS_DAEMON_FILE (destination))
     {
       /* Fall back to default move */
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, "%s", "Move not supported");
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, "Move not supported");
       return FALSE;
     }
   
@@ -2120,8 +2120,8 @@ g_daemon_file_monitor_dir (GFile* file,
     {
       g_mount_info_unref (mount_info);
       dbus_message_unref (reply);
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		   "%s", _("Invalid return value from monitor_dir"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+			   _("Invalid return value from monitor_dir"));
       return NULL;
     }
   
@@ -2169,8 +2169,8 @@ g_daemon_file_monitor_file (GFile* file,
     {
       g_mount_info_unref (mount_info);
       dbus_message_unref (reply);
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		   "%s", _("Invalid return value from monitor_file"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+			   _("Invalid return value from monitor_file"));
       return NULL;
     }
   
@@ -2219,21 +2219,11 @@ append_to_async_cb (DBusMessage *reply,
                     GCancellable *cancellable,
                     gpointer callback_data)
 {
-  DBusMessageIter iter;
   guint32 fd_id;
   StreamOpenParams *open_params;
 
   open_params = g_slice_new0 (StreamOpenParams);
 
-  if (!dbus_message_iter_init (reply, &iter) ||
-      (dbus_message_iter_get_arg_type (&iter) != DBUS_TYPE_STRUCT))
-    {
-      g_simple_async_result_set_error (result,
-				       G_IO_ERROR, G_IO_ERROR_FAILED,
-				       "Invalid return value from append_to_async");
-      goto failure;
-    }
-
   if (!dbus_message_get_args (reply, NULL,
 			      DBUS_TYPE_UINT32, &fd_id,
 			      DBUS_TYPE_BOOLEAN, &open_params->can_seek,
@@ -2307,21 +2297,11 @@ create_async_cb (DBusMessage *reply,
                  GCancellable *cancellable,
                  gpointer callback_data)
 {
-  DBusMessageIter iter;
   guint32 fd_id;
   StreamOpenParams *open_params;
 
   open_params = g_slice_new0 (StreamOpenParams);
 
-  if (!dbus_message_iter_init (reply, &iter) ||
-      (dbus_message_iter_get_arg_type (&iter) != DBUS_TYPE_STRUCT))
-    {
-      g_simple_async_result_set_error (result,
-				       G_IO_ERROR, G_IO_ERROR_FAILED,
-				       "Invalid return value from create_async");
-      goto failure;
-    }
-
   if (!dbus_message_get_args (reply, NULL,
 			      DBUS_TYPE_UINT32, &fd_id,
 			      DBUS_TYPE_BOOLEAN, &open_params->can_seek,
@@ -2576,21 +2556,11 @@ replace_async_cb (DBusMessage *reply,
                   GCancellable *cancellable,
                   gpointer callback_data)
 {
-  DBusMessageIter iter;
   guint32 fd_id;
   StreamOpenParams *open_params;
 
   open_params = g_slice_new0 (StreamOpenParams);
 
-  if (!dbus_message_iter_init (reply, &iter) ||
-      (dbus_message_iter_get_arg_type (&iter) != DBUS_TYPE_STRUCT))
-    {
-      g_simple_async_result_set_error (result,
-				       G_IO_ERROR, G_IO_ERROR_FAILED,
-				       "Invalid return value from replace_async");
-      goto failure;
-    }
-
   if (!dbus_message_get_args (reply, NULL,
 			      DBUS_TYPE_UINT32, &fd_id,
 			      DBUS_TYPE_BOOLEAN, &open_params->can_seek,
@@ -2624,9 +2594,12 @@ g_daemon_file_replace_async (GFile                      *file,
 {
   dbus_bool_t dbus_make_backup = make_backup;
   guint32 dbus_flags = flags;
-  guint16 mode = 0;
+  guint16 mode = 2;
+  
+  if (etag == NULL)
+    etag = "";
 
-  do_async_path_call (file, 
+  do_async_path_call (file,
                       G_VFS_DBUS_MOUNT_OP_OPEN_FOR_WRITE,
                       cancellable,
                       callback, user_data,
