@@ -531,12 +531,32 @@ list_trash_dirs (void)
   GList *topdirs_info;
   struct stat statbuf;
   gboolean has_trash_files;
+  int stat_result;
 
   dirs = NULL;
   has_trash_files = FALSE;
   
   home_trash = g_build_filename (g_get_user_data_dir (), "Trash", NULL);
-  if (lstat (home_trash, &statbuf) == 0 &&
+
+  stat_result = g_lstat (home_trash, &statbuf);
+
+  /* If the home trash directory doesn't exist at this point, we must create
+   * it in order to monitor it. */
+  if (stat_result != 0)
+    {
+      gchar *home_trash_files = g_build_filename (home_trash, "files", NULL);
+      gchar *home_trash_info  = g_build_filename (home_trash, "info", NULL);
+
+      g_mkdir_with_parents (home_trash_files, 0700);
+      g_mkdir_with_parents (home_trash_info, 0700);
+
+      g_free (home_trash_files);
+      g_free (home_trash_info);
+
+      stat_result = g_lstat (home_trash, &statbuf);
+    }
+
+  if (stat_result == 0 &&
       S_ISDIR (statbuf.st_mode))
     {
       dirs = g_list_prepend (dirs, home_trash);
@@ -552,8 +572,11 @@ list_trash_dirs (void)
     {
       mount = l->data;
       
-      topdir = g_unix_mount_get_mount_path (mount);
-      topdirs = g_list_prepend (topdirs, g_strdup (topdir));
+      if (!g_unix_mount_is_system_internal (mount) )
+        {
+          topdir = g_unix_mount_get_mount_path (mount);
+          topdirs = g_list_prepend (topdirs, g_strdup (topdir));
+        }
       
       g_unix_mount_free (mount);
     }
@@ -986,7 +1009,10 @@ add_extra_trash_info (GFileInfo *file_info,
                   g_file_info_set_attribute_string (file_info, G_FILE_ATTRIBUTE_STANDARD_EDIT_NAME, NULL);
                 }
               else
-                g_file_info_set_attribute_string (file_info, G_FILE_ATTRIBUTE_STANDARD_EDIT_NAME, display_name);
+		{
+		  g_file_info_set_attribute_string (file_info, G_FILE_ATTRIBUTE_STANDARD_EDIT_NAME, display_name);
+		  g_file_info_set_attribute_string (file_info, G_FILE_ATTRIBUTE_STANDARD_COPY_NAME, display_name);
+		}
                 
               g_file_info_set_display_name (file_info, display_name);
 
