@@ -34,6 +34,7 @@
 static GVolumeMonitor *monitor = NULL;
 static DBusConnection *connection = NULL;
 static GType the_volume_monitor_type;
+static const char *the_dbus_name = NULL;
 
 static void monitor_try_create (void);
 
@@ -45,6 +46,11 @@ _g_icon_serialize (GIcon *icon)
   g_return_val_if_fail (icon != NULL, NULL);
   g_return_val_if_fail (G_IS_ICON (icon), NULL);
 
+  /* We encode icons as a series of whitespace-separated tokens.
+   * The first token is the type of the icon. To help decoding, 
+   * the number of tokens is prepended as the first token (not 
+   * included in the count).
+   */
   if (G_IS_FILE_ICON (icon))
     {
       GFileIcon *file_icon = G_FILE_ICON (icon);
@@ -56,9 +62,8 @@ _g_icon_serialize (GIcon *icon)
       uri = g_file_get_uri (file);
       escaped_uri = g_uri_escape_string (uri, NULL, TRUE);
 
-      ret = g_strdup_printf ("GFileIcon %s", escaped_uri);
+      ret = g_strdup_printf ("2 GFileIcon %s", escaped_uri);
 
-      g_object_unref (file);
       g_free (uri);
       g_free (escaped_uri);
     }
@@ -73,7 +78,8 @@ _g_icon_serialize (GIcon *icon)
                     "names", &names,
                     NULL);
 
-      s = g_string_new ("GThemedIcon");
+      s = g_string_new (0); 
+      g_string_append_printf (s, "%d GThemedIcon", g_strv_length (names) + 1);
 
       if (names != NULL)
         {
@@ -91,6 +97,35 @@ _g_icon_serialize (GIcon *icon)
 
       g_strfreev (names);
     }
+  else if (G_IS_EMBLEMED_ICON (icon))
+    {
+      char *base, *s;
+      GList *emblems, *e;
+      int n;
+      GString *str;
+
+      /* GEmblemedIcons are encoded as 
+       * 
+       *   <num_tokens> GEmblemedIcon <num_emblems> [<origin> <encoded_icon> ]*
+       */
+      str = g_string_new ("");
+      base = _g_icon_serialize (g_emblemed_icon_get_icon (G_EMBLEMED_ICON (icon)));
+      emblems = g_emblemed_icon_get_emblems (G_EMBLEMED_ICON (icon));
+      g_string_append_printf (str, "GEmblemedIcon %s %d", base, g_list_length (emblems));
+      n = atoi (base) + 2;
+      g_free (base);
+      for (e = emblems; e; e = e->next)
+        {
+          s = _g_icon_serialize (g_emblem_get_icon (G_EMBLEM (e->data)));
+          g_string_append_printf (str, " %d %s", g_emblem_get_origin (G_EMBLEM (e->data)), s);
+          n += atoi (s) + 2;
+          g_free (s);
+        }
+       
+      s = g_string_free (str, FALSE);
+      ret = g_strdup_printf ("%d %s", n + 1, s);
+      g_free (s);
+    }
   else
     {
       ret = NULL;
@@ -330,6 +365,8 @@ append_mount (GMount *mount, DBusMessageIter *iter_array)
   gboolean can_unmount;
   GVolume *volume;
   char *volume_id;
+  char **x_content_types;
+  int n;
 
   dbus_message_iter_open_container (iter_array, DBUS_TYPE_STRUCT, NULL, &iter_struct);
 
@@ -349,6 +386,8 @@ append_mount (GMount *mount, DBusMessageIter *iter_array)
 
   if (name == NULL)
     name = g_strdup ("");
+  if (uuid == NULL)
+    uuid = g_strdup ("");
 
   dbus_message_iter_append_basic (&iter_struct, DBUS_TYPE_STRING, &id);
   dbus_message_iter_append_basic (&iter_struct, DBUS_TYPE_STRING, &name);
@@ -359,7 +398,12 @@ append_mount (GMount *mount, DBusMessageIter *iter_array)
   dbus_message_iter_append_basic (&iter_struct, DBUS_TYPE_STRING, &volume_id);
 
   dbus_message_iter_open_container (&iter_struct, DBUS_TYPE_ARRAY, "s", &iter_x_content_types_array);
-  /* TODO: append x-content types */
+  x_content_types = (char **) g_object_get_data (G_OBJECT (mount), "x-content-types");
+  if (x_content_types != NULL)
+    {
+      for (n = 0; x_content_types[n] != NULL; n++)
+        dbus_message_iter_append_basic (&iter_x_content_types_array, DBUS_TYPE_STRING, &(x_content_types[n]));
+    }
   dbus_message_iter_close_container (&iter_struct, &iter_x_content_types_array);
 
   g_free (volume_id);
@@ -877,6 +921,7 @@ emit_signal (DBusConnection *connection, const char *signal_name, void *object,
 
   message = dbus_message_new_signal ("/", "org.gtk.Private.RemoteVolumeMonitor", signal_name);
   dbus_message_iter_init_append (message, &iter);
+  dbus_message_iter_append_basic (&iter, DBUS_TYPE_STRING, &the_dbus_name);
   dbus_message_iter_append_basic (&iter, DBUS_TYPE_STRING, &id);
 
   func (object, &iter);
@@ -937,9 +982,18 @@ mount_changed (GVolumeMonitor *monitor, GMount *mount, DBusConnection *connectio
   emit_signal (connection, "MountChanged", mount, (AppendFunc) append_mount);
 }
 
+static void
+mount_sniff_x_content_type (GMount *mount)
+{
+  char **x_content_types;
+  x_content_types = g_mount_guess_content_type_sync (mount, TRUE, NULL, NULL);
+  g_object_set_data_full (G_OBJECT (mount), "x-content-types", x_content_types, (GDestroyNotify) g_strfreev);
+}
+
 static void
 mount_added (GVolumeMonitor *monitor, GMount *mount, DBusConnection *connection)
 {
+  mount_sniff_x_content_type (mount);
   emit_signal (connection, "MountAdded", mount, (AppendFunc) append_mount);
 }
 
@@ -980,6 +1034,8 @@ static void
 monitor_try_create (void)
 {
   GVolumeMonitorClass *klass;
+  GList *mounts;
+  GList *l;
 
   monitor = NULL;
   klass = G_VOLUME_MONITOR_CLASS (g_type_class_ref (the_volume_monitor_type));
@@ -1005,6 +1061,12 @@ monitor_try_create (void)
       goto fail;
     }
 
+  mounts = g_volume_monitor_get_mounts (monitor);
+  for (l = mounts; l != NULL; l = l->next)
+    mount_sniff_x_content_type (G_MOUNT (l->data));
+  g_list_foreach (mounts, (GFunc) g_object_unref, NULL);
+  g_list_free (mounts);
+
  fail:
   if (klass != NULL)
     g_type_class_unref (klass);
@@ -1031,6 +1093,7 @@ g_vfs_proxy_volume_monitor_daemon_main (int argc,
    */
 
   the_volume_monitor_type = volume_monitor_type;
+  the_dbus_name = dbus_name;
 
   /* try and create the monitor */
   monitor_try_create ();
